@@ -12,7 +12,7 @@
  * method hashPassword based on code from the phpLDAPadmin development team (http://phpldapadmin.sourceforge.net/).
  * method randomSalt based on code from the phpLDAPadmin development team (http://phpldapadmin.sourceforge.net/).
  *
- * Copyright (C) 2005-2014, The Roundcube Dev Team
+ * Copyright (C) The Roundcube Dev Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,10 +34,11 @@ class rcube_ldap_password
     {
         $rcmail = rcmail::get_instance();
         require_once 'Net/LDAP2.php';
+        require_once __DIR__ . '/ldap_simple.php';
 
         // Building user DN
         if ($userDN = $rcmail->config->get('password_ldap_userDN_mask')) {
-            $userDN = self::substitute_vars($userDN);
+            $userDN = rcube_ldap_simple_password::substitute_vars($userDN);
         }
         else {
             $userDN = $this->search_userdn($rcmail);
@@ -65,10 +66,10 @@ class rcube_ldap_password
             'binddn'    => $binddn,
             'bindpw'    => $bindpw,
             'basedn'    => $rcmail->config->get('password_ldap_basedn'),
-            'host'      => $rcmail->config->get('password_ldap_host'),
-            'port'      => $rcmail->config->get('password_ldap_port'),
+            'host'      => $rcmail->config->get('password_ldap_host', 'localhost'),
+            'port'      => $rcmail->config->get('password_ldap_port', '389'),
             'starttls'  => $rcmail->config->get('password_ldap_starttls'),
-            'version'   => $rcmail->config->get('password_ldap_version'),
+            'version'   => $rcmail->config->get('password_ldap_version', '3'),
         );
 
         // Connecting using the configuration array
@@ -79,13 +80,13 @@ class rcube_ldap_password
             return PASSWORD_CONNECT_ERROR;
         }
 
-        $force        = $rcmail->config->get('password_ldap_force_replace');
-        $pwattr       = $rcmail->config->get('password_ldap_pwattr');
+        $force        = $rcmail->config->get('password_ldap_force_replace', true);
+        $pwattr       = $rcmail->config->get('password_ldap_pwattr', 'userPassword');
         $lchattr      = $rcmail->config->get('password_ldap_lchattr');
         $smbpwattr    = $rcmail->config->get('password_ldap_samba_pwattr');
         $smblchattr   = $rcmail->config->get('password_ldap_samba_lchattr');
         $samba        = $rcmail->config->get('password_ldap_samba');
-        $encodage     = $rcmail->config->get('password_ldap_encodage');
+        $encodage     = $rcmail->config->get('password_ldap_encodage', 'crypt');
 
         // Support multiple userPassword values where desired.
         // multiple encodings can be specified separated by '+' (e.g. "cram-md5+ssha")
@@ -161,10 +162,10 @@ class rcube_ldap_password
 
         $ldapConfig = array (
             'basedn'    => $rcmail->config->get('password_ldap_basedn'),
-            'host'      => $rcmail->config->get('password_ldap_host'),
-            'port'      => $rcmail->config->get('password_ldap_port'),
+            'host'      => $rcmail->config->get('password_ldap_host', 'localhost'),
+            'port'      => $rcmail->config->get('password_ldap_port', '389'),
             'starttls'  => $rcmail->config->get('password_ldap_starttls'),
-            'version'   => $rcmail->config->get('password_ldap_version'),
+            'version'   => $rcmail->config->get('password_ldap_version', '3'),
         );
 
         // allow anonymous searches
@@ -179,8 +180,8 @@ class rcube_ldap_password
             return '';
         }
 
-        $base   = self::substitute_vars($rcmail->config->get('password_ldap_search_base'));
-        $filter = self::substitute_vars($rcmail->config->get('password_ldap_search_filter'));
+        $base   = rcube_ldap_simple_password::substitute_vars($rcmail->config->get('password_ldap_search_base'));
+        $filter = rcube_ldap_simple_password::substitute_vars($rcmail->config->get('password_ldap_search_filter'));
         $options = array (
             'scope' => 'sub',
             'attributes' => array(),
@@ -196,28 +197,4 @@ class rcube_ldap_password
 
         return $userDN;
     }
-
-    /**
-     * Substitute %login, %name, %domain, %dc in $str
-     * See plugin config for details
-     */
-    static function substitute_vars($str)
-    {
-        $str = str_replace('%login', $_SESSION['username'], $str);
-        $str = str_replace('%l', $_SESSION['username'], $str);
-
-        $parts = explode('@', $_SESSION['username']);
-
-        if (count($parts) == 2) {
-            $dc = 'dc='.strtr($parts[1], array('.' => ',dc=')); // hierarchal domain string
-
-            $str = str_replace('%name', $parts[0], $str);
-            $str = str_replace('%n', $parts[0], $str);
-            $str = str_replace('%dc', $dc, $str);
-            $str = str_replace('%domain', $parts[1], $str);
-            $str = str_replace('%d', $parts[1], $str);
-        }
-
-        return $str;
-    }
 }
