@@ -48,7 +48,8 @@ function rcube_text_editor(config, id)
       toolbar_items_size: 'small',
       extended_valid_elements: 'font[face|size|color|style],span[id|class|align|style]',
       fontsize_formats: '8pt 9pt 10pt 11pt 12pt 14pt 18pt 24pt 36pt',
-      valid_children: '+body[style]',
+      // Allow style tag, have to be allowed inside body/div/blockquote (#7088)
+      valid_children: '+body[style],+blockquote[style],+div[style]',
       relative_urls: false,
       remove_script_host: false,
       convert_urls: false, // #1486944
@@ -330,7 +331,7 @@ function rcube_text_editor(config, id)
         if (is_sig)
           data = data.replace(sig_mark, "\n" + signature.text);
 
-        input.val(data).focus();
+        input.val(data).focus().trigger('input');
         rcmail.set_caret_pos(input.get(0), 0);
       };
 
@@ -663,7 +664,7 @@ function rcube_text_editor(config, id)
       title: rcmail.get_label('select' + type),
       width: 500,
       html: '<div id="image-selector" class="image-selector file-upload"><ul id="image-selector-list" class="attachmentslist"></ul></div>',
-      buttons: [{text: 'Cancel', onclick: function() { ref.file_browser_close(); }}]
+      buttons: [{text: rcmail.get_label('close'), onclick: function() { ref.file_browser_close(); }}]
     });
 
     rcmail.env.file_browser_field = field_name;
