@@ -41,6 +41,7 @@ tinymce.addI18n('ja',{
 "Heading 4": "\u898b\u51fa\u3057 4",
 "Heading 5": "\u898b\u51fa\u3057 5",
 "Heading 6": "\u898b\u51fa\u3057 6",
+"Preformatted": "Preformatted",
 "Div": "Div",
 "Pre": "Pre",
 "Code": "\u30b3\u30fc\u30c9",
@@ -101,9 +102,9 @@ tinymce.addI18n('ja',{
 "Focus to toolbar": "\u30c4\u30fc\u30eb\u30d0\u30fc\u306b\u30d5\u30a9\u30fc\u30ab\u30b9",
 "Focus to element path": "\u8981\u7d20\u30d1\u30b9\u306b\u30d5\u30a9\u30fc\u30ab\u30b9",
 "Focus to contextual toolbar": "\u30b3\u30f3\u30c6\u30ad\u30b9\u30c8\u30c4\u30fc\u30eb\u30d0\u30fc\u306b\u30d5\u30a9\u30fc\u30ab\u30b9",
-"Insert link (if link plugin activated)": "\u30ea\u30f3\u30af\u3092\u633f\u5165 \uff08\u30ea\u30f3\u30af\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642\uff09",
-"Save (if save plugin activated)": "\u4fdd\u5b58\uff08\u4fdd\u5b58\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642\uff09",
-"Find (if searchreplace plugin activated)": "\u691c\u7d22\uff08\u7f6e\u63db\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642\uff09",
+"Insert link (if link plugin activated)": "\u30ea\u30f3\u30af\u3092\u633f\u5165 (\u30ea\u30f3\u30af\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642)",
+"Save (if save plugin activated)": "\u4fdd\u5b58 (\u4fdd\u5b58\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642)",
+"Find (if searchreplace plugin activated)": "\u691c\u7d22(\u7f6e\u63db\u30d7\u30e9\u30b0\u30a4\u30f3\u6709\u52b9\u6642)",
 "Plugins installed ({0}):": "\u30a4\u30f3\u30b9\u30c8\u30fc\u30eb\u6e08\u30d7\u30e9\u30b0\u30a4\u30f3 ({0}):",
 "Premium plugins:": "\u30d7\u30ec\u30df\u30a2\u30e0\u30d7\u30e9\u30b0\u30a4\u30f3:",
 "Learn more...": "\u8a73\u7d30...",
